@@ -34,19 +34,16 @@ class ReviewDAO(object):
         self.data = {}
         self._current = None
 
-    def add_fact(self, key, title, value, unit=None):
+    def add_fact(self, key, value):
         self.facts[key] = {
             'key': key,
-            'value': value,
-            'title': title,
-            'unit': unit
+            'value': value
         }
 
-    def add_violation(self, key, title, description, points):
+    def add_violation(self, key, value, points):
         self.violations.append({
             'key': key,
-            'title': title,
-            'description': description,
+            'value': value,
             'points': points
         })
 
@@ -157,11 +154,12 @@ class Reviewer(object):
         except (lxml.etree.XMLSyntaxError, lxml.etree.ParserError):
             self._current.html = None
 
-            self.add_violation(
-                key='invalid.content',
-                title='Invalid Content',
-                description='Fail to parse content from %s' % url,
-                points=1000)
+            # can't do this there, this is not a validator
+            #self.add_violation(
+                #key='invalid.content',
+                #title='Invalid Content',
+                #description='Fail to parse content from %s' % url,
+                #points=1000)
 
         self.run_facters()
         self.wait_for_async_requests()
@@ -224,11 +222,11 @@ class Reviewer(object):
                 response.text
             ))
 
-    def add_fact(self, key, value, title, unit='value'):
-        self.review_dao.add_fact(key, title, value, unit)
+    def add_fact(self, key, value):
+        self.review_dao.add_fact(key, value)
 
-    def add_violation(self, key, title, description, points):
-        self.review_dao.add_violation(key, title, description, points)
+    def add_violation(self, key, value, points):
+        self.review_dao.add_violation(key, value, points)
 
     def save_review(self):
         url = self.get_url('/page/%s/review/' % (self.page_uuid))
